@@ -3,7 +3,7 @@
 #' Maximum Likelihood Estimation of the IAR-Gamma model.
 #'
 #' @param y Array with the time series observations
-#' @param sT Array with the irregular observational times
+#' @param st Array with the irregular observational times
 #'
 #' @return A list with the following components:
 #' \itemize{
@@ -18,19 +18,19 @@
 #'
 #' @seealso
 #'
-#' \code{\link{gentime}}, \code{\link{IARg.sample}}, \code{\link{IAR.phi.gamma}}
+#' \code{\link{gentime}}, \code{\link{IARgsample}}, \code{\link{IARphigamma}}
 #'
 #'
 #' @examples
 #' n=300
 #' set.seed(6714)
 #' st<-gentime(n)
-#' y<-IARg.sample(n,phi=0.9,st,sigma2=1,mu=1)
-#' model<-IAR.gamma(y$y, sT=st)
+#' y<-IARgsample(phi=0.9,st=st,n=n,sigma2=1,mu=1)
+#' model<-IARgamma(y$y, st=st)
 #' phi=model$phi
 #' muest=model$mu
 #' sigmaest=model$sigma
-IAR.gamma<-function(y, sT)
+IARgamma<-function(y, st)
 {
   aux<-1e10
   value<-1e10
@@ -40,7 +40,7 @@ IAR.gamma<-function(y, sT)
     phi=runif(1)
     mu=mean(y)*runif(1)
     sigma=var(y)*runif(1)
-    optim<-nlminb(start=c(phi,mu,sigma),objective=IAR.phi.gamma,y=y,sT=sT,lower=c(0,0.0001,0.0001),upper=c(0.9999,mean(y),var(y)))
+    optim<-nlminb(start=c(phi,mu,sigma),objective=IARphigamma,y=y,st=st,lower=c(0,0.0001,0.0001),upper=c(0.9999,mean(y),var(y)))
     value<-optim$objective
     if(aux>value)
     {
