@@ -3,7 +3,7 @@
 #' Maximum Likelihood Estimation of the IAR model parameter phi. The estimation procedure uses the Kalman Filter to find the maximum of the likelihood.
 #'
 #' @param y Array with the time series observations.
-#' @param sT Array with the irregular observational times.
+#' @param st Array with the irregular observational times.
 #' @param delta Array with the measurements error standard deviations.
 #' @param zero.mean logical; if true, the array y has zero mean; if false, y has a mean different from zero.
 #' @param standarized logical; if true, the array y is standarized; if false, y contains the raw time series
@@ -19,20 +19,20 @@
 #'
 #' @seealso
 #'
-#' \code{\link{gentime}}, \code{\link{IAR.sample}}, \code{\link{arima}},\code{\link{IAR.phi.kalman}}
+#' \code{\link{gentime}}, \code{\link{IARsample}}, \code{\link{arima}},\code{\link{IARphikalman}}
 #'
 #' @examples
 #' set.seed(6714)
 #' st<-gentime(n=100)
-#' y<-IAR.sample(phi=0.99,n=100,st)
+#' y<-IARsample(phi=0.99,st=st,n=100)
 #' y<-y$series
-#' phi=IAR.kalman(y=y,sT=st)$phi
+#' phi=IARkalman(y=y,st=st)$phi
 #' print(phi)
-IAR.kalman<-function (y, sT, delta=0,zero.mean='TRUE',standarized='TRUE')
+IARkalman<-function (y, st, delta=0,zero.mean='TRUE',standarized='TRUE')
 {
   if(sum(delta)==0){
     delta=rep(0,length(y))}
-  out = optimize(IAR.phi.kalman, interval = c(0, 1), y = y, t = sT, yerr=delta,zero.mean=zero.mean,standarized=standarized)
+  out = optimize(IARphikalman, interval = c(0, 1), y = y, st = st, yerr=delta,zeroMean=zero.mean,standarized=standarized)
   phi = out$minimum
   ll = out$objective
   return(list(phi = phi, kalman = ll))
